``flask_admin.model``
=====================

.. automodule:: flask_admin.model

    .. autoclass:: BaseModelView
        :members:
        :exclude-members: can_create, can_edit, can_delete, list_template, edit_template,
                          create_template, column_list, column_exclude_list, column_labels,
                          column_formatters, column_type_formatters, column_display_pk,
                          column_descriptions, column_default_sort,
                          column_sortable_list, column_searchable_list, column_filters,
                          column_choices,
                          form, form_columns, form_excluded_columns, form_args,
                          form_base_class,
                          form_overrides, action_disallowed_list,
                          form_widget_args, form_extra_fields,
                          form_ajax_refs, form_create_rules,
                          form_edit_rules,
                          page_size, can_set_page_size

        .. autoattribute:: can_create
        .. autoattribute:: can_edit
        .. autoattribute:: can_delete

        .. autoattribute:: list_template
        .. autoattribute:: edit_template
        .. autoattribute:: create_template

        .. autoattribute:: column_list
        .. autoattribute:: column_exclude_list
        .. autoattribute:: column_labels
        .. autoattribute:: column_descriptions
        .. autoattribute:: column_formatters
        .. autoattribute:: column_type_formatters
        .. autoattribute:: column_display_pk

        .. autoattribute:: column_sortable_list
        .. autoattribute:: column_searchable_list
        .. autoattribute:: column_default_sort
        .. autoattribute:: column_choices

        .. autoattribute:: column_filters

        .. autoattribute:: form
        .. autoattribute:: form_base_class
        .. autoattribute:: form_columns
        .. autoattribute:: form_excluded_columns
        .. autoattribute:: form_args
        .. autoattribute:: form_overrides
        .. autoattribute:: form_widget_args
        .. autoattribute:: form_extra_fields
        .. autoattribute:: form_ajax_refs

        .. autoattribute:: form_create_rules
        .. autoattribute:: form_edit_rules

        .. autoattribute:: action_disallowed_list

        .. autoattribute:: page_size
        .. autoattribute:: can_set_page_size
